import 'vuetify/dist/vuetify.min.css'
import '@mdi/font/css/materialdesignicons.css'

import Notifications from '@remotehq/vue-notification'
import { get_vuetify_options, i18n } from 'FerdaJS/app.config'
import i18next from 'i18next'
import Backend from 'i18next-chained-backend'
import Vue from 'vue'
import VueCookies from 'vue-cookies'
import Vuetify from 'vuetify/lib'

import AuctionBaseView from './components/AuctionBaseView.vue'
import AuctionContactDetail from './components/common/AuctionContactDetail.vue'
import { get_ferda_auction_i18next_options, store } from './main.config'
import router from './router'

Vue.use(VueCookies)
Vue.use(Vuetify)
Vue.use(Notifications)

// Listen for store changes from Ferda and sync them with the store here
document.addEventListener('storechange', event => {
    const { payload, type } = event.detail
    const value = payload.value ? payload.value : payload

    if (store._mutations[type]) {
        store.commit(type, value)
    }
})

const destination = document.currentScript.dataset.destination

document.addEventListener('ferda-loaded', async({ detail }) => {
    await i18next.use(Backend).init(get_ferda_auction_i18next_options(detail.settings.django_settings.version))
    store.commit('auction_settings/set_auction_base_url', detail.settings.django_settings.auction.api_url)

    if (destination === 'contact-detail') {
        const contact_data = JSON.parse(document.querySelector('#contact-data').textContent)
        const auctionEl = document.querySelector('#auction')
        const options = get_vuetify_options()

        if (auctionEl) {
            new Vue({
                el: '#auction',
                name: 'AuctionIndex',
                vuetify: new Vuetify(options),
                i18n,
                components: { AuctionBaseView },
                store,
                router,
                render: createElement => createElement(AuctionBaseView),
            })
        }

        const auction_section_el = document.createElement('div')
        auction_section_el.id = 'auction-section'
        document.querySelector('.v-main__wrap > div > div:nth-child(4) > div').prepend(auction_section_el)

        new Vue({
            el: '#auction-section',
            name: 'FerdaAuction',
            vuetify: new Vuetify(options),
            i18n,
            store,
            render: createElement => createElement(AuctionContactDetail, {
                props: {
                    contact_id: contact_data.object_uuid,
                },
            }),
        })
    }

    if (destination === 'auction-module') {
        const auctionEl = document.querySelector('#auction')
        if (auctionEl) {
            new Vue({
                el: '#auction',
                name: 'AuctionIndex',
                vuetify: new Vuetify(get_vuetify_options()),
                i18n,
                components: { AuctionBaseView },
                store,
                router,
                render: createElement => createElement(AuctionBaseView),
            })
        }
    }
})

window.addEventListener('popstate', () => {
    location.reload()
})

export { i18next }
